;+
; NAME:
;  skysclim
; PURPOSE:
;  Compute stretch range for a hard stretch on the background in an image.
; DESCRIPTION:
; CATEGORY:
;  Image display
; CALLING SEQUENCE:
;  skysclim,image,lowval,hival,meanval,sigma
; INPUTS:
;  image - 2-d image to compute stretch range for.
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
;  NPTS - Maximum number of points to grab at random from image for scaling
;           information.  Default=601.
; OUTPUTS:
;  lowval - Low DN value for sky stretch
;  hival  - High DN value for sky stretch
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;  96/01/07 - Marc W. Buie
;  2000/02/29, MWB, added NPTS keyword
;-
pro skysclim,image,lowval,hival,meanval,sigma,NPTS=npts

   if badpar(npts,[0,2,3],0,caller='SKYSCLIM: (NPTS) ',default=601) then return

   idx=randomu(seed,min([npts,n_elements(image)]))*(n_elements(image)-1)
;   sub=image[idx]
;   s=sort(sub)
;   subs=sub[s]
;   meanval=subs[50]
;   sigma=stdev(subs[20:80])

   robomean,image[idx],2.0,0.5,meanval,dummy,sigma

   lowval=meanval-3.0*sigma
   hival=meanval+5.0*sigma

end
